Module: Relaton::Cli
- Included in:
- Command, SubcommandCollection, SubcommandDb
- Defined in:
- lib/relaton-cli.rb,
lib/relaton/cli.rb,
lib/relaton/cli/command.rb,
lib/relaton/cli/version.rb,
lib/relaton/cli/data_fetcher.rb,
lib/relaton/cli/relaton_file.rb,
lib/relaton/cli/subcommand_db.rb,
lib/relaton/cli/xml_convertor.rb,
lib/relaton/cli/base_convertor.rb,
lib/relaton/cli/yaml_convertor.rb,
lib/relaton/cli/xml_to_html_renderer.rb,
lib/relaton/cli/subcommand_collection.rb
Defined Under Namespace
Modules: DataFetcher
Classes: BaseConvertor, Command, RelatonDb, RelatonFile, SubcommandCollection, SubcommandDb, XMLConvertor, XmlToHtmlRenderer, YAMLConvertor
Constant Summary
collapse
- VERSION =
"1.16.0".freeze
Class Method Summary
collapse
Class Method Details
.parse_xml(doc) ⇒ RelatonBib::BibliographicItem, RelatonIsoBib::IsoBibliongraphicItem
74
75
76
77
78
79
80
|
# File 'lib/relaton/cli.rb', line 74
def parse_xml(doc)
if (proc = Cli.processor(doc))
proc.from_xml(doc.to_s)
else
RelatonBib::XMLParser.from_xml(doc.to_s)
end
end
|
.processor(doc) ⇒ RelatonIso::Processor, ...
87
88
89
90
91
92
93
|
# File 'lib/relaton/cli.rb', line 87
def processor(doc)
docid = doc.at "docidentifier"
proc = get_proc docid
return proc if proc
Relaton::Registry.instance.by_type(docid&.text&.match(/^\w+/)&.to_s)
end
|
.relaton(dir) ⇒ Relaton::Db
Relaton
Based on current setup, we need to initiate a Db instance to register all of it’s supported processor backends. To make it easier we have added it as a class method so we can use this whenever necessary.
67
68
69
|
# File 'lib/relaton/cli.rb', line 67
def relaton(dir)
RelatonDb.instance.db dir
end
|
.start(arguments) ⇒ Object
54
55
56
|
# File 'lib/relaton/cli.rb', line 54
def start(arguments)
Relaton::Cli::Command.start(arguments)
end
|
.version ⇒ Object
41
42
43
44
45
46
47
48
49
50
51
52
|
# File 'lib/relaton/cli.rb', line 41
def version
registry = Relaton::Registry.instance
puts "CLI => #{Relaton::Cli::VERSION}"
puts "relaton => #{Relaton::VERSION}"
puts "relaton-bib => #{RelatonBib::VERSION}"
puts "relaton-iso-bib => #{RelatonIsoBib::VERSION}"
registry.processors.each_key do |k|
klass = "#{k.to_s.split('_').map(&:capitalize).join}::VERSION"
version = Kernel.const_get(klass)
puts "#{k.to_s.sub('_', '-')} => #{version}"
end
end
|