Module: Relaton::Cli

Defined in:
lib/relaton/cli.rb,
lib/relaton/cli/command.rb,
lib/relaton/cli/version.rb,
lib/relaton/cli/relaton_file.rb,
lib/relaton/cli/xml_convertor.rb,
lib/relaton/cli/base_convertor.rb,
lib/relaton/cli/yaml_convertor.rb,
lib/relaton/cli/xml_to_html_renderer.rb

Defined Under Namespace

Classes: BaseConvertor, Command, RelatonFile, XMLConvertor, XmlToHtmlRenderer, YAMLConvertor

Constant Summary collapse

VERSION =
"0.1.4".freeze

Class Method Summary collapse

Class Method Details

.relatonObject

Relaton

Based on current setup, we need to initiate a Db instance to register all of it’s supported processor backends. To make it easier we have added it as a class method so we can use this whenever necessary.



18
19
20
# File 'lib/relaton/cli.rb', line 18

def self.relaton
  @relaton ||= Relaton::Db.new("#{Dir.home}/.relaton/cache", nil)
end

.start(arguments) ⇒ Object



7
8
9
# File 'lib/relaton/cli.rb', line 7

def self.start(arguments)
  Relaton::Cli::Command.start(arguments)
end